==> jbpm-flow-1.12.0.Final-sources.jar: org/jbpm/process/core/datatype/impl/type/IntegerDataType.java <==
/*
 * Copyright 2010 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jbpm.process.core.datatype.impl.type;

import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

import org.jbpm.process.core.datatype.DataType;

/**
 * Representation of an integer datatype.
 */
public class IntegerDataType implements DataType {

    private static final long serialVersionUID = 510l;

    public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException {
    }

    public void writeExternal(ObjectOutput out) throws IOException {
    }

    public boolean verifyDataType(final Object value) {
        if (value instanceof Integer) {
            return true;
        } else if (value == null) {
            return true;
        } else {
            return false;
        }
    }

    public Object readValue(String value) {
        return Integer.valueOf(value);
    }

    public String writeValue(Object value) {
        Integer i = (Integer) value;
        return i == null ? "" : i.toString();
    }

    public String getStringType() {
        return "java.lang.Integer";
    }

}

==> jbpm-flow-1.41.0.Final-sources.jar: org/jbpm/process/core/datatype/impl/type/IntegerDataType.java <==
/*
 * Copyright 2010 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jbpm.process.core.datatype.impl.type;

import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

import org.jbpm.process.core.datatype.DataType;

/**
 * Representation of an integer datatype.
 */
public class IntegerDataType implements DataType {

    private static final long serialVersionUID = 510l;

    @Override
    public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException {
    }

    @Override
    public void writeExternal(ObjectOutput out) throws IOException {
    }

    @Override
    public boolean verifyDataType(final Object value) {
        return value == null || value instanceof Integer;
    }

    @Override
    public Object readValue(String value) {
        return Integer.valueOf(value);
    }

    @Override
    public String writeValue(Object value) {
        Integer i = (Integer) value;
        return i == null ? "" : i.toString();
    }

    @Override
    public String getStringType() {
        return "java.lang.Integer";
    }

    @Override
    public Class<?> getObjectClass() {
        return Integer.class;
    }

}
